# Change Log

## [0.0.4](https://github.com/dldevinc/aioja/tree/v0.0.4) - 2020-10-15
- Fix `{% extends %}`, `{% include %}` and `{% import %}` tags
- `enable_async` is now forced to be `True`
- Added common imports to `__init__.py`

## [0.0.3](https://github.com/dldevinc/aioja/tree/v0.0.3) - 2020-10-15
- Add more loaders
- Make `list_templates` method async

## [0.0.2](https://github.com/dldevinc/aioja/tree/v0.0.2) - 2020-10-14
- Allow to pass DSN to AioRedisBytecodeCache
- Add typing
- Make `enable_async` optional

## [0.0.1](https://github.com/dldevinc/aioja/tree/v0.0.1) - 2020-10-13
- First release
